@@ -6,6 +6,7 @@ import hashlib
 import json
 import requests
 import warnings
+from random import randint
 
 def hash_password(password):
     """
@@ -24,10 +25,22 @@ class Timespan(IntEnum):
 
 class GrowattApi:
     server_url = 'https://server-api.growatt.com/'
+    agent_identifier = "Dalvik/2.1.0 (Linux; U; Android 12; https://github.com/indykoning/PyPi_GrowattServer)"
+
+    def __init__(self, add_random_user_id=False, agent_identifier=None):
+        if (agent_identifier != None):
+          self.agent_identifier = agent_identifier
+
+        #If a random user id is required, generate a 5 digit number and add it to the user agent
+        if (add_random_user_id):
+          random_number = ''.join(["{}".format(randint(0,9)) for num in range(0,5)])
+          self.agent_identifier += " - " + random_number
 
-    def __init__(self):
         self.session = requests.Session()
 
+        headers = {'User-Agent': self.agent_identifier}
+        self.session.headers.update(headers)
+
     def __get_date_string(self, timespan=None, date=None):
         if timespan is not None:
          assert timespan in Timespan
@@ -112,7 +125,7 @@ class GrowattApi:
         if not is_password_hashed:
             password = hash_password(password)
 
-        response = self.session.post(self.get_url('newLoginAPI.do'), data={
+        response = self.session.post(self.get_url('newTwoLoginAPI.do'), data={
             'userName': username,
             'password': password
         })
